import path from 'node:path';
import express from 'express';
import dotenv from 'dotenv';
import Middleware from './middleware/App.js';
import Routes from './routes/App.js';
import MemoryDB from './database/MemoryDB.js';

const srcFolder = path.dirname(process.argv[1]);
const productPath = path.resolve(path.join(srcFolder, '..', '..'));
const backendPath = path.join(productPath, 'backend');
const frontendPath = path.join(productPath, 'frontend');
const staticFilesPath = path.join(frontendPath, 'dist');

const envPath = path.join(backendPath, '.env');
dotenv.config({ path: envPath });

const port = process.env.SRV_PORT || 8080;
const app = express();
Middleware.register(app);
Routes.register(app);

app.use(express.static(staticFilesPath));
app.use('*', express.static(staticFilesPath));

(async () => {
  try {
    await MemoryDB.connect().catch(err => {
      console.log('Falha ao conectar ao banco de dados');
      throw err;
    });
    app.listen(port, () => {
      console.log(`Listening in ${port}`);
    });
  } catch(err) {
    console.error(err);
  }
})();
